@@ -8,11 +8,11 @@ AnyEvent::XMPP - An implementation of the XMPP Protocol
 
 =head1 VERSION
 
-Version 0.3
+Version 0.4
 
 =cut
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 =head1 SYNOPSIS
 
@@ -93,10 +93,6 @@ For SASL authentication
 
 For stringprep profiles to handle JIDs.
 
-=item L<Net::SSLeay>
-
-For SSL connections.
-
 =item L<Digest::SHA1>
 
 For component authentication and old-style authentication.
@@ -118,6 +114,17 @@ Here are some notes to the last releases (release of this version is at top):
 
 =over 4
 
+=item * 0.4
+
+Minor fixes and feature enhancements: Added old_style_ssl option for direct
+port 5223 SSL connections. Providing 'get_own_contact' for keeping
+track of own resources.
+
+The L<AnyEvent::XMPP::Ext::MUC> extension was rewritten and provides a more
+sane API now.
+
+For details consult the Changes file in the distribution.
+
 =item * 0.3
 
 Fixed some small bugs and improved documentation a bit, especially w.r.t.
@@ -198,25 +205,6 @@ in RFC 3920 and RFC 3921 (see also L<AnyEvent::XMPP::Connection> and
 L<AnyEvent::XMPP::IM::Connection>). But I also try to provide a high level API for
 easier usage for instant messaging tasks and clients (eg. L<AnyEvent::XMPP::Client>).
 
-=head1 A note about TLS
-
-This module also supports TLS, as the specification of XMPP requires an
-implementation to support TLS.
-
-Maybe there are still some bugs in the handling of TLS in L<AnyEvent::XMPP::Connection>.
-So keep an eye on TLS with this module. If you encounter any problems it would be
-very helpful if you could debug them or at least send me a detailed report on how
-to reproduce the problem.
-
-(As I use this module myself I don't expect TLS to be completely broken, but it
-might break under different circumstances than I have here.  Those
-circumstances might be a different load of data pumped through the TLS
-connection.)
-
-I mainly expect problems where available data isn't properly read from the socket
-or written to it. You might want to take a look at the C<debug_send> and C<debug_recv>
-events in L<AnyEvent::XMPP::Connection>.
-
 =head1 Supported extensions
 
 See L<AnyEvent::XMPP::Ext> for a list.
@@ -344,7 +332,7 @@ You can also look for information at:
 
   IRC Network: http://freenode.net/
   Server     : chat.freenode.net
-  Channel    : #net_xmpp2
+  Channel    : #ae_xmpp
 
   Feel free to join and ask questions!
 
